contexttools.detach_tempo_marks_attached_to_component
=====================================================

.. autofunction:: abjad.tools.contexttools.detach_tempo_marks_attached_to_component.detach_tempo_marks_attached_to_component
